from datetime import datetime
import os
import subprocess
import time


def invalid(path):
    try:
        os.stat(path)
        return not os.path.ismount(path)
    except Exception as e:
        return True


def refresh_if_needed(source_server, source, target, options):
    print(datetime.strftime(datetime.now(), "%y-%m-%d %H:%M:%S"))
    if not invalid(target):
        print("Still mounted")
        return
    unmount = subprocess.call(["fusermount", "-u", target])
    if unmount != 0:
        print("Failed unmount")
    mount_command = [
        "sshfs",
        source_server + ":" + source,
        target,
        "-o",
        options,
    ]
    mount = subprocess.call(mount_command)
    if mount != 0:
        print("Failed mount")


def autorefreshing_sshfs_utility(source_server, source, target, options):
    while True:
        time.sleep(1)
        try:
            refresh_if_needed(source_server, source, target, options)
        except KeyboardInterrupt:
            break
        except Exception as e:
            print(e)
            pass



import argparse

from .auto_retry_sshfs import autorefreshing_sshfs_utility


def cli():
    parser = argparse.ArgumentParser()
    parser.add_argument(
        "--source-server", required=True, help="The server to sshfs from"
    )
    parser.add_argument("--source-path", required=True, help="The path to sshfs from")
    parser.add_argument("--target-path", required=True, help="The path to sshfs to")
    parser.add_argument(
        "--sshfs-options",
        help="The options to use",
        default="reconnect,ServerAliveInterval=15,ServerAliveCountMax=3,allow_other",
    )
    args = parser.parse_args()
    autorefreshing_sshfs_utility(
        args.source_server, args.source_path, args.target_path, args.sshfs_options
    )



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="auto-retry-sshfs",
    version="1.0.0",
    author="Kavi Gupta",
    author_email="autoretrysshfs@kavigupta.org",
    description="Ridiculous tool that automatically retries sshfs for you over an unreliable connection.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/kavigupta/auto-retry-sshfs",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
    install_requires=[],
    entry_points={
        "console_scripts": ["auto-retry-sshfs=auto_retry_sshfs.cli:cli"],
    },
)
